summaryrefslogtreecommitdiffstats
path: root/Source/cmMakefileTargetGenerator.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'Source/cmMakefileTargetGenerator.cxx')
-rw-r--r--Source/cmMakefileTargetGenerator.cxx5
1 files changed, 3 insertions, 2 deletions
diff --git a/Source/cmMakefileTargetGenerator.cxx b/Source/cmMakefileTargetGenerator.cxx
index a1f4141..1e01f11 100644
--- a/Source/cmMakefileTargetGenerator.cxx
+++ b/Source/cmMakefileTargetGenerator.cxx
@@ -702,11 +702,12 @@ cmMakefileTargetGenerator
vars.Defines = definesString.c_str();
// At the moment, it is assumed that C and C++ have both
// assembly and preprocessor capabilities. The same is true for the
// ability to export compile commands
bool lang_has_preprocessor = ((lang == "C") ||
- (lang == "CXX"));
+ (lang == "CXX") ||
+ (lang == "Fortran"));
bool const lang_has_assembly = lang_has_preprocessor;
bool const lang_can_export_cmds = lang_has_preprocessor;
@@ -702,11 +702,12 @@ cmMakefileTargetGenerator
vars.Defines = definesString.c_str();
- // At the moment, it is assumed that C and C++ have both
+ // At the moment, it is assumed that C, C++, and Fortran have both
// assembly and preprocessor capabilities. The same is true for the
// ability to export compile commands